@@ -1,14 +1,14 @@
 #! /usr/bin/env python
 # -*- coding: iso-8859-1 -*-
 # vi:ts=4:et
-# $Id: setup_win32_ssl.py,v 1.17 2004/05/24 12:57:21 kjetilja Exp $
+# $Id: setup_win32_ssl.py,v 1.24 2004/12/22 14:28:08 mfx Exp $
 
 import os, sys, string
 assert sys.platform == "win32", "Only for building on Win32 with SSL and zlib"
 
 
-CURL_DIR = r"c:\src\build\curl-7.12-ssl"
-OPENSSL_DIR = r"c:\src\build\openssl-0.9.7d"
+CURL_DIR = r"c:\src\build\pycurl\curl-7.12.3-ssl"
+OPENSSL_DIR = r"c:\src\build\pycurl\openssl-0.9.7e"
 sys.argv.insert(1, "--curl-dir=" + CURL_DIR)
 
 from setup import *
@@ -19,12 +19,12 @@ setup_args["name"] = "pycurl-ssl"
 for l in ("libeay32.lib", "ssleay32.lib",):
     ext.extra_objects.append(os.path.join(OPENSSL_DIR, "out32", l))
 
-if 0:
-    ZLIB_DIR = r"c:\src\build\zlib-1.1.4"
-    ext.extra_objects.append(os.path.join(ZLIB_DIR, "zlib114.lib"))
-else:
-    ##ext.extra_link_args.append("zlib114.lib")
-    ext.extra_objects.append(r"c:\src\pool\zlib-1.1.4\pool\win32\vc6\zlib.lib")
+pool = "\\" + r"pool\win32\vc6" + "\\"
+if string.find(sys.version, "MSC v.1310") >= 0:
+    pool = "\\" + r"pool\win32\vc71" + "\\"
+ext.extra_objects.append(r"c:\src\pool\zlib-1.2.2" + pool + "zlib.lib")
+ext.extra_objects.append(r"c:\src\pool\c-ares-20041212" + pool + "ares.lib")
+ext.extra_objects.append(r"c:\src\pool\libidn-0.5.12" + pool + "idn.lib")
 
 
 if __name__ == "__main__":
