@@ -1,10 +1,20 @@
 #! /usr/bin/env python
+# -*- coding: iso-8859-1 -*-
 # vi:ts=4:et
-# $Id: test.py,v 1.10 2002/08/29 14:39:20 mfx Exp $
+# $Id: test.py,v 1.15 2003/04/21 18:46:10 mfx Exp $
 
 import sys, threading, time
 import pycurl
 
+# We should ignore SIGPIPE when using pycurl.NOSIGNAL - see the libcurl
+# documentation `libcurl-the-guide' for more info.
+try:
+    import signal
+    from signal import SIGPIPE, SIG_IGN
+    signal.signal(signal.SIGPIPE, signal.SIG_IGN)
+except ImportError:
+    pass
+
 
 class Test(threading.Thread):
     def __init__(self, url, ofile):
@@ -14,11 +24,12 @@ class Test(threading.Thread):
         self.curl.setopt(pycurl.WRITEDATA, ofile)
         self.curl.setopt(pycurl.FOLLOWLOCATION, 1)
         self.curl.setopt(pycurl.MAXREDIRS, 5)
+        self.curl.setopt(pycurl.NOSIGNAL, 1)
 
     def run(self):
         self.curl.perform()
         self.curl.close()
-        sys.stdout.write('.')
+        sys.stdout.write(".")
         sys.stdout.flush()
 
 
@@ -37,7 +48,7 @@ fileno = 0
 # Start one thread per URI in parallel
 t1 = time.time()
 for url in urls:
-    f = open(str(fileno), 'w')
+    f = open(str(fileno), "wb")
     t = Test(url, f)
     t.start()
     threads.append((t, f))
@@ -47,17 +58,17 @@ for thread, file in threads:
     thread.join()
     file.close()
 t2 = time.time()
-print '\n** Multithreading, %d seconds elapsed for %d uris' % (int(t2-t1), len(urls))
+print "\n** Multithreading, %d seconds elapsed for %d uris" % (int(t2-t1), len(urls))
 
 # Start one thread per URI in sequence
 fileno = 0
 t1 = time.time()
 for url in urls:
-    f = open(str(fileno), 'w')
+    f = open(str(fileno), "wb")
     t = Test(url, f)
     t.start()
     fileno = fileno + 1
     t.join()
     f.close()
 t2 = time.time()
-print '\n** Singlethreading, %d seconds elapsed for %d uris' % (int(t2-t1), len(urls))
+print "\n** Singlethreading, %d seconds elapsed for %d uris" % (int(t2-t1), len(urls))
